Module socialization.ccs.json_ws_passive_service
================================================

Classes
-------

`JSONWebsocketPassiveService(port=7654)`
:   

    ### Descendants

    * socialization.ccs.base_goddess_service.BaseGoddessService

    ### Methods

    `echo(self, ws, message)`
    :

    `get_server_coroutine(self)`
    :